@@ -1,5 +1,5 @@
 # src/tessif/__init__.py
-"""Tessif - Transforming Energy Suppy System (M)odellIng Framework."""
+"""Tessif - Transforming Energy Supply System (M)odellIng Framework."""
 from importlib.metadata import version
 
 __version__ = version(__name__)
